@@ -5,7 +5,7 @@ build_time_vars = {'ABIFLAGS': '',
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
- 'AR': 'ar',
+ 'AR': '/usr/bin/ar',
  'ARFLAGS': 'rcs',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code',
  'BASECPPFLAGS': '',
@@ -16,7 +16,7 @@ build_time_vars = {'ABIFLAGS': '',
  'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'i386-unknown-openbsd7.1',
+ 'BUILD_GNU_TYPE': 'riscv64-unknown-openbsd7.2',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
@@ -27,7 +27,7 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-O2 -pipe',
- 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
+ 'CONFIGURE_CFLAGS_NODIST': '-flto -g -std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
@@ -35,20 +35,25 @@ build_time_vars = {'ABIFLAGS': '',
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
- 'CONFIGURE_LDFLAGS_NODIST': '',
+ 'CONFIGURE_LDFLAGS_NODIST': '-flto -g',
  'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' '--with-fpectl' "
                 "'--with-threads' '--enable-ipv6' '--with-system-expat' "
-                "'--with-system-ffi' '--enable-loadable-sqlite-extensions' "
-                "'--prefix=/usr/local' '--sysconfdir=/etc' "
-                "'--mandir=/usr/local/man' '--infodir=/usr/local/info' "
-                "'--localstatedir=/var' '--disable-silent-rules' "
-                "'--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' "
-                "'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
+                "'--with-system-ffi' "
+                "'--with-tcltk-includes=-I/usr/local/include/tcl8.6 "
+                "-I/usr/local/include/tk8.6 -I/usr/X11R6/include' "
+                "'--with-tcltk-libs=-L/usr/X11R6/lib -ltcl86 -ltk86' "
+                "'--enable-loadable-sqlite-extensions' '--with-lto' "
+                "'--enable-optimizations' '--prefix=/usr/local' "
+                "'--sysconfdir=/etc' '--mandir=/usr/local/man' "
+                "'--infodir=/usr/local/info' '--localstatedir=/var' "
+                "'--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' "
+                "'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' "
+                "'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/tmp/pobj/Python-3.9.13/Python-3.9.13/coverage.info',
- 'COVERAGE_REPORT': '/build/tmp/pobj/Python-3.9.13/Python-3.9.13/lcov-report',
+ 'COVERAGE_INFO': '/local/pobj/Python-3.9.14/Python-3.9.14/coverage.info',
+ 'COVERAGE_REPORT': '/local/pobj/Python-3.9.14/Python-3.9.14/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
@@ -151,7 +156,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DECL_RTLD_LOCAL': 1,
  'HAVE_DECL_RTLD_MEMBER': 0,
  'HAVE_DECL_RTLD_NODELETE': 1,
- 'HAVE_DECL_RTLD_NOLOAD': 0,
+ 'HAVE_DECL_RTLD_NOLOAD': 1,
  'HAVE_DECL_RTLD_NOW': 1,
  'HAVE_DECL_TZNAME': 0,
  'HAVE_DEVICE_MACROS': 1,
@@ -209,8 +214,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GAMMA': 1,
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
- 'HAVE_GCC_ASM_FOR_X87': 1,
- 'HAVE_GCC_UINT128_T': 0,
+ 'HAVE_GCC_ASM_FOR_X87': 0,
+ 'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
@@ -261,7 +266,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 1,
+ 'HAVE_LARGEFILE_SUPPORT': 0,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -518,16 +523,16 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'i386-unknown-openbsd7.1',
+ 'HOST_GNU_TYPE': 'riscv64-unknown-openbsd7.2',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.9 /usr/local/include/python3.9',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.9',
- 'INSTALL': '/build/tmp/pobj//Python-3.9.13/bin/install -c',
- 'INSTALL_DATA': '/build/tmp/pobj//Python-3.9.13/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/build/tmp/pobj//Python-3.9.13/bin/install -c -s -m 755',
- 'INSTALL_SCRIPT': '/build/tmp/pobj//Python-3.9.13/bin/install -c -m 755',
- 'INSTALL_SHARED': '/build/tmp/pobj//Python-3.9.13/bin/install -c -m 755',
+ 'INSTALL': '/local/pobj/Python-3.9.14/bin/install -c',
+ 'INSTALL_DATA': '/local/pobj/Python-3.9.14/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/local/pobj/Python-3.9.14/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/local/pobj/Python-3.9.14/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/local/pobj/Python-3.9.14/bin/install -c -m 755',
  'INSTSONAME': 'libpython3.9.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
@@ -557,8 +562,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
- 'LLVM_PROF_FILE': '',
- 'LLVM_PROF_MERGER': '',
+ 'LLVM_PROF_FILE': 'LLVM_PROFILE_FILE="code-%p.profclangr"',
+ 'LLVM_PROF_MERGER': '/usr/bin/llvm-profdata merge -output=code.profclangd '
+                     '*.profclangr',
  'LN': 'ln',
  'LOCALMODLIBS': '',
  'MACHDEP': 'openbsd7',
@@ -611,8 +617,8 @@ build_time_vars = {'ABIFLAGS': '',
                 'Parser/tokenizer.o',
  'PEGEN_HEADERS': '\\',
  'PEGEN_OBJS': '\\',
- 'PGO_PROF_GEN_FLAG': '',
- 'PGO_PROF_USE_FLAG': '',
+ 'PGO_PROF_GEN_FLAG': '-fprofile-instr-generate',
+ 'PGO_PROF_USE_FLAG': '-fprofile-instr-use=code.profclangd',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
@@ -634,48 +640,51 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
                              '-Wunreachable-code -DNDEBUG -O2 -pipe   -fPIC '
-                             '-O2 -pipe -O2 -pipe -std=c99 -Wextra '
+                             '-O2 -pipe -O2 -pipe -flto -g -std=c99 -Wextra '
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden -I/usr/local/include '
+                             '-fprofile-instr-use=code.profclangd '
                              '-I./Include/internal -I. -I./Include '
                              '-I/usr/local/include -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG '
               '-O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
- 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
+ 'PY_CFLAGS_NODIST': '-flto -g -std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden -I/usr/local/include '
-                     '-I./Include/internal',
+                     '-fprofile-instr-use=code.profclangd -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
-                   '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -std=c99 '
-                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto -g '
+                   '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-I/usr/local/include -I./Include/internal -I. -I./Include '
-                   '-I/usr/local/include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L/usr/local/lib/ '
-                    '-L/build/tmp/pobj//Python-3.9.13/Python-3.9.13 '
+                   '-I/usr/local/include -fprofile-instr-use=code.profclangd '
+                   '-I./Include/internal -I. -I./Include -I/usr/local/include '
+                   '-fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-L/usr/local/lib/ -flto -g '
+                    '-L/local/pobj/Python-3.9.14/Python-3.9.14 '
                     '-L/usr/local/lib/',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-L/usr/local/lib/',
- 'PY_LDFLAGS_NODIST': '-L/build/tmp/pobj//Python-3.9.13/Python-3.9.13 '
+ 'PY_LDFLAGS_NODIST': '-flto -g -L/local/pobj/Python-3.9.14/Python-3.9.14 '
                       '-L/usr/local/lib/',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
-                        '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe '
-                        '-std=c99 -Wextra -Wno-unused-result '
+                        '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto '
+                        '-g -std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden -I/usr/local/include '
+                        '-fprofile-instr-use=code.profclangd '
                         '-I./Include/internal -I. -I./Include '
                         '-I/usr/local/include -fPIC',
  'Py_DEBUG': 0,
@@ -686,7 +695,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.9.13/Python-3.9.13',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/local/pobj/Python-3.9.14/Python-3.9.14',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SHELL': '/bin/sh',
@@ -699,18 +708,18 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 12,
+ 'SIZEOF_LONG': 8,
+ 'SIZEOF_LONG_DOUBLE': 16,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 4,
+ 'SIZEOF_PTHREAD_T': 8,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 4,
+ 'SIZEOF_SIZE_T': 8,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 4,
- 'SIZEOF_VOID_P': 4,
+ 'SIZEOF_UINTPTR_T': 8,
+ 'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-39',
@@ -723,14 +732,15 @@ build_time_vars = {'ABIFLAGS': '',
  'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
- 'TCLTK_INCLUDES': '',
- 'TCLTK_LIBS': '',
+ 'TCLTK_INCLUDES': '-I/usr/local/include/tcl8.6 -I/usr/local/include/tk8.6 '
+                   '-I/usr/X11R6/include',
+ 'TCLTK_LIBS': '-L/usr/X11R6/lib -ltcl86 -ltk86',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.9.13/Python-3.9.13 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/local/pobj/Python-3.9.14/Python-3.9.14 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.9.13/Python-3.9.13 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/local/pobj/Python-3.9.14/Python-3.9.14 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -751,10 +761,10 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 1,
+ 'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/tmp/pobj/Python-3.9.13/Python-3.9.13',
- 'abs_srcdir': '/build/tmp/pobj/Python-3.9.13/Python-3.9.13',
+ 'abs_builddir': '/local/pobj/Python-3.9.14/Python-3.9.14',
+ 'abs_srcdir': '/local/pobj/Python-3.9.14/Python-3.9.14',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
